@@ -613,10 +613,12 @@ class Call(WorkflowNode):
             for name, expr in self.inputs.items():
                 try:
                     decl = self.callee.available_inputs[name]
+                    # treat input with default as optional, with or without the ? type quantifier
+                    decltype = decl.type.copy(optional=True) if decl.expr else decl.type
                     errors.try1(
-                        lambda expr=expr, decl=decl: expr.infer_type(
+                        lambda expr=expr, decltype=decltype: expr.infer_type(
                             type_env, stdlib, check_quant=check_quant, struct_types=struct_types
-                        ).typecheck(decl.type)
+                        ).typecheck(decltype)
                     )
                 except KeyError:
                     errors.append(Error.NoSuchInput(expr, name))
