@@ -162,22 +162,37 @@ class StateMachine:
 
         self.values_to_json = values_to_json  # pyre-ignore
 
+        # Preprocess inputs: if None value is supplied for an input declared with a default but
+        # without the ? type quantifier, remove the binding entirely so that the default will be
+        # used. In contrast, if the input declaration has an -explicitly- optional type, then we'll
+        # allow the supplied None to override any default.
+        input_decls = workflow.available_inputs
+        self.inputs = self.inputs.filter(
+            lambda b: not (
+                isinstance(b.value, Value.Null)
+                and b.name in input_decls
+                and input_decls[b.name].expr
+                and not input_decls[b.name].type.optional
+            )
+        )
+
         workflow_nodes = (workflow.inputs or []) + workflow.body + (workflow.outputs or [])
         workflow_nodes.append(WorkflowOutputs(workflow))
 
-        # TODO: by topsorting all section bodies we can ensure that when we schedule an additional
-        # job, all its dependencies will already have been scheduled, increasing
-        # flexibility/compatibility with various backends.
         for node in workflow_nodes:
             deps = node.workflow_node_dependencies
             if isinstance(node, Tree.Decl):
                 # strike the dependencies of any decl node whose value is supplied in the inputs
-                if inputs.has_binding(node.name):
+                if self.inputs.has_binding(node.name):
                     deps = set()
             self._schedule(
                 _Job(id=node.workflow_node_id, node=node, dependencies=deps, scatter_stack=[])
             )
 
+        # TODO: by topsorting all section bodies we could ensure that when we schedule an
+        # additional job, all its dependencies will already have been scheduled, increasing
+        # flexibility/compatibility with various backends.
+
         # sanity check
         assert "outputs" in self.jobs
         known_jobs = set(self.waiting)
@@ -366,14 +381,22 @@ class StateMachine:
             # check workflow inputs for additional inputs supplied to this call
             for b in self.inputs.enter_namespace(job.node.name):
                 call_inputs = call_inputs.bind(b.name, b.value)
-            # coerce inputs to required types
+
+            # coerce inputs to required types (treating inputs with defaults as optional even if
+            # they don't have the ? type quantifier)
             assert isinstance(job.node.callee, (Tree.Task, Tree.Workflow))
             callee_inputs = job.node.callee.available_inputs
             call_inputs = call_inputs.map(
                 lambda b: Env.Binding(
                     b.name,
                     (
-                        b.value.coerce(callee_inputs[b.name].type)
+                        b.value.coerce(
+                            (
+                                callee_inputs[b.name].type.copy(optional=True)
+                                if callee_inputs[b.name].expr
+                                else callee_inputs[b.name].type
+                            )
+                        )
                         if b.name in callee_inputs
                         else b.value
                     ),
